CREATE TABLE DOMAINS
(
  ID NUMBER(11) NOT NULL,
  NAME VARCHAR2(64) NOT NULL,
  PRIMARY KEY(ID),
  UNIQUE(NAME)
);

CREATE TABLE DOMAINS_MESSAGES
(
  DOMAINID NUMBER(11) DEFAULT 0 NOT NULL,
  CONFIGNAME VARCHAR2(64) DEFAULT '' NOT NULL ,
  CONFIGVALUE LONG NOT NULL,
  PRIMARY KEY  (DOMAINID, CONFIGNAME),
  FOREIGN KEY (DOMAINID) REFERENCES DOMAINS(ID) ON DELETE CASCADE
);

CREATE TABLE DOMAINS_SETTINGS
(
  DOMAINID NUMBER(11) DEFAULT 0 NOT NULL,
  CONFIGNAME VARCHAR2(64) DEFAULT '' NOT NULL ,
  CONFIGVALUE LONG NOT NULL,
  PRIMARY KEY  (DOMAINID, CONFIGNAME),
  FOREIGN KEY (DOMAINID) REFERENCES DOMAINS(ID) ON DELETE CASCADE
);

CREATE TABLE GROUPS
(
  DOMAINID NUMBER(11) DEFAULT 0 NOT NULL,
  ID NUMBER(11) NOT NULL,
  NAME VARCHAR2(64) DEFAULT '' NOT NULL,
  PRIMARY KEY  (ID),
  UNIQUE (DOMAINID,NAME),
  FOREIGN KEY (DOMAINID) REFERENCES DOMAINS(ID) ON DELETE CASCADE
);

CREATE TABLE GROUPS_SETTINGS
(
  GROUPID NUMBER(11) DEFAULT 0 NOT NULL ,
  CONFIGNAME VARCHAR2(64) DEFAULT '' NOT NULL ,
  CONFIGVALUE LONG NOT NULL,
  PRIMARY KEY  (GROUPID,CONFIGNAME),
  FOREIGN KEY (GROUPID) REFERENCES GROUPS(ID) ON DELETE CASCADE
);

CREATE TABLE SERVER_SETTINGS
(
  CONFIGNAME VARCHAR2(64) DEFAULT '' NOT NULL,
  CONFIGVALUE LONG NOT NULL,
  PRIMARY KEY  (CONFIGNAME)
);


CREATE TABLE USERS
(
  DOMAINID NUMBER(11) DEFAULT 0 NOT NULL,
  ID NUMBER(11) NOT NULL,
  NAME VARCHAR2(64) DEFAULT '' NOT NULL,
  PRIMARY KEY  (ID),
  UNIQUE (DOMAINID,NAME),
  FOREIGN KEY (DOMAINID) REFERENCES DOMAINS(ID) ON DELETE CASCADE
);


CREATE TABLE USERS_SETTINGS
(
  USERID NUMBER(11) DEFAULT 0 NOT NULL,
  CONFIGNAME VARCHAR2(64) DEFAULT '' NOT NULL,
  CONFIGVALUE LONG NOT NULL,
  PRIMARY KEY  (USERID,CONFIGNAME),
  FOREIGN KEY (USERID) REFERENCES USERS(ID) ON DELETE CASCADE
);


CREATE SEQUENCE DOMAINS_ID
  START WITH 1
  MAXVALUE 99999999999
  MINVALUE 1
  NOCYCLE
  NOCACHE
  ORDER;

CREATE SEQUENCE GROUPS_ID
	START WITH 1
	MAXVALUE 99999999999
	MINVALUE 1
	NOCYCLE
	NOCACHE
  ORDER;

CREATE SEQUENCE USERS_ID
	START WITH 1
	MAXVALUE 99999999999
	MINVALUE 1
	NOCYCLE
	NOCACHE
  ORDER;

CREATE OR REPLACE TRIGGER DOMAINS$BEFORE
BEFORE INSERT
ON DOMAINS
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
BEGIN
  SELECT DOMAINS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
END;
/

CREATE OR REPLACE TRIGGER GROUPS$BEFORE
BEFORE INSERT
ON GROUPS
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
BEGIN
  SELECT GROUPS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
END;
/

CREATE OR REPLACE TRIGGER USERS$BEFORE
BEFORE INSERT
ON USERS
REFERENCING NEW AS NEW OLD AS OLD
FOR EACH ROW
BEGIN
  SELECT USERS_ID.NEXTVAL INTO :NEW.ID FROM DUAL;
END;
/

